###############################################################################
#	Filename:	RotFelix.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	Loads Felix Savali, tactical officer, and configures animations.
#	
#	Created:	3/28/00 -	Erik Novales
###############################################################################

import App
import CharacterPaths

#kDebugObj = App.CPyDebug()

###############################################################################
#	CreateCharacter()
#
#	Create Felix by building his character and placing him on the passed in set.
#	Create his menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacter(pSet):
#	kDebugObj.Print("Creating Felix")
	
	if (pSet.GetObject("Tactical") != None):
		return(App.CharacterClass_Cast(pSet.GetObject("Tactical")))

	CharacterPaths.UpdatePaths()
	# Create the character
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyMaleL/BodyMaleL.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcHeadNIFPath + "Headklingon/klingon_head.nif", None)
	pRotFelix = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyMaleL/BodyMaleL.nif", CharacterPaths.g_pcHeadNIFPath + "Headklingon/klingon_head.nif")
	pRotFelix.ReplaceBodyAndHead(CharacterPaths.g_pcBodyTexPath + "../BridgeCrew/Felix/felix_body.tga", CharacterPaths.g_pcHeadTexPath + "../Ramblers/heads/HeadKlingon/kartok_head.tga")

	pRotFelix.SetCharacterName("Felix")

	# Add the character to the set
	pSet.AddObjectToSet(pRotFelix, "Tactical")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pRotFelix)

	# Set up character configuration
	pRotFelix.SetSize(App.CharacterClass.LARGE)
	pRotFelix.SetGender(App.CharacterClass.MALE)
	pRotFelix.SetStanding(0)
	pRotFelix.SetRandomAnimationChance(1.0)
	pRotFelix.SetBlinkChance(0.1)
	pRotFelix.SetAudioMode(App.CharacterClass.CAM_EXTREMELY_VOCAL)
	pRotFelix.SetDatabase("data/TGL/Bridge Crew General.tgl")

	LoadSounds()

	pRotFelix.AddFacialImage("Blink0", CharacterPaths.g_pcHeadTexPath + "../Ramblers/heads/HeadKlingon/kartok_head.tga")
	pRotFelix.AddFacialImage("Blink1", CharacterPaths.g_pcHeadTexPath + "../Ramblers/heads/HeadKlingon/kartok_head.tga")
	pRotFelix.AddFacialImage("Blink2", CharacterPaths.g_pcHeadTexPath + "../Ramblers/heads/HeadKlingon/kartok_head.tga")
	pRotFelix.SetBlinkStages(3)

	pRotFelix.AddFacialImage("SpeakA", CharacterPaths.g_pcHeadTexPath + "../Ramblers/heads/HeadKlingon/kartok_head.tga")
	pRotFelix.AddFacialImage("SpeakE", CharacterPaths.g_pcHeadTexPath + "../Ramblers/heads/HeadKlingon/kartok_head.tga")
	pRotFelix.AddFacialImage("SpeakU", CharacterPaths.g_pcHeadTexPath + "../Ramblers/heads/HeadKlingon/kartok_head.tga")
	pRotFelix.SetAnimatedSpeaking(1)

	pMenusDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Menus.tgl")
	pTop = App.TopWindow_GetTopWindow()
	pTacticalControlWindow = App.TacticalControlWindow_GetTacticalControlWindow()
	pRotFelix.SetMenu(pTacticalControlWindow.FindMenu(pMenusDatabase.GetString("Tactical")))
	App.g_kLocalizationManager.Unload(pMenusDatabase)

	pRotFelix.AddAnimation("Place", "Bridge.Characters.CommonAnimations.Standing")
	pRotFelix.SetLocation("")

#	kDebugObj.Print("Finished creating Felix")
	return pRotFelix

###############################################################################
#	CreateCharacterNoSounds()
#
#	Create Felix by building his character and placing him on the passed in set.
#	Create his menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacterNoSounds(pSet):
#	kDebugObj.Print("Creating Felix")
	
	import Bridge.TacticalMenuHandlers
	Bridge.TacticalMenuHandlers.CreateMenusNoSounds(pRotFelix)

	# Create the character
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyMaleL/BodyMaleL.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcHeadNIFPath + "HeadFelix/felix_head.nif", None)
	pRotFelix = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyMaleL/BodyMaleL.nif", CharacterPaths.g_pcHeadNIFPath + "HeadFelix/felix_head.nif")
	pRotFelix.ReplaceBodyAndHead(CharacterPaths.g_pcBodyTexPath + "../BridgeCrew/Felix/felix_body.tga", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Felix/felix_head.tga")

	pRotFelix.SetCharacterName("Felix")

	# Add the character to the set
	pSet.AddObjectToSet(pRotFelix, "Tactical")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pRotFelix)

	# Set up character configuration
	pRotFelix.SetSize(App.CharacterClass.LARGE)
	pRotFelix.SetGender(App.CharacterClass.MALE)
	pRotFelix.SetStanding(1)
	pRotFelix.SetHidden(1)
	pRotFelix.SetRandomAnimationChance(0.75)
	pRotFelix.SetBlinkChance(0.1)
	pRotFelix.SetAudioMode(App.CharacterClass.CAM_EXTREMELY_VOCAL)
	pRotFelix.SetDatabase("data/TGL/Bridge Crew General.tgl")

	pBrex.AddAnimation("Place", "Bridge.Characters.CommonAnimations.Standing")
	pBrex.SetLocation("")

#	kDebugObj.Print("Finished creating Felix")
	return pRotFelix


###############################################################################
#	CreateCharacterNoMenu()
#
#	Create Felix by building his character and placing him on the passed in set.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacterNoMenu(pSet):
#	kDebugObj.Print("Creating Felix")
	
	# Create the character
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyMaleL/BodyMaleL.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcHeadNIFPath + "HeadFelix/felix_head.nif", None)
	pRotFelix = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyMaleL/BodyMaleL.nif", CharacterPaths.g_pcHeadNIFPath + "HeadFelix/felix_head.nif")
	pRotFelix.ReplaceBodyAndHead(CharacterPaths.g_pcBodyTexPath + "BodyMaleM/FedGold_body.tga", CharacterPaths.g_pcHeadTexPath + "HeadFelix/felix_head.tga")

	pRotFelix.SetCharacterName("Felix")

	# Add the character to the set
	pSet.AddObjectToSet(pRotFelix, "Tactical")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pRotFelix)

	# Set up character configuration
	pRotFelix.SetSize(App.CharacterClass.LARGE)
	pRotFelix.SetGender(App.CharacterClass.MALE)
	pRotFelix.SetStanding(1)
	pRotFelix.SetHidden(1)
	pRotFelix.SetRandomAnimationChance(0.75)
	pRotFelix.SetBlinkChance(0.1)
	pRotFelix.SetAudioMode(App.CharacterClass.CAM_EXTREMELY_VOCAL)
	pRotFelix.SetDatabase("data/TGL/Bridge Crew General.tgl")

	pRotFelix.AddAnimation("Place", "Bridge.Characters.CommonAnimations.Standing")
	pRotFelix.SetLocation("")

#	kDebugObj.Print("Finished creating Felix")
	return pRotFelix


###############################################################################
#	ConfigureForShip()
#
#	Configure ourselves for the particular ship object.  This involves setting
#	up range watchers that tell us how to report.
#
#	Args:	pSet	- the Set object
#			pShip	- the player's ship
#
#	Return:	none
###############################################################################
def ConfigureForShip(pSet, pShip):
	# Get our character object
	pRotFelix = App.CharacterClass_Cast(pSet.GetObject("Tactical"))
	if (pRotFelix == None):
#		kDebugObj.Print("******* Tactical officer not found *********")
		return

#	kDebugObj.Print("Attaching menu to Tactical..")
	import Bridge.TacticalCharacterHandlers
	Bridge.TacticalCharacterHandlers.AttachMenuToTactical(pRotFelix)


###############################################################################
#	ConfigureForRotarran()
#
#	Configure ourselves for the Rotarran bridge
#
#	Args:	pRotFelix	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForRotarran(pRotFelix):
#	kDebugObj.Print("Configuring Felix for the Rot bridge")

	# Clear out any old animations from another configuration
	pRotFelix.ClearAnimations()

	# Register animation mappings
	pRotFelix.AddAnimation("SeatedRotTactical", "Bridge.Characters.RotLargeAnimations.Rot_seated_t")
	#pRotFelix.AddAnimation("EBL1LToT", "Bridge.Characters.RotLargeAnimations.EBMoveFromL1ToT")
	#pRotFelix.AddAnimation("EBTacticalToL1", "Bridge.Characters.RotLargeAnimations.EBMoveFromTToL1")
	pRotFelix.AddAnimation("RotTacticalTurnCaptain", "Bridge.Characters.RotLargeAnimations.RotTurnAtTTowardsCaptain")
	pRotFelix.AddAnimation("RotTacticalBackCaptain", "Bridge.Characters.RotLargeAnimations.RotTurnBackAtTFromCaptain")

	pRotFelix.AddAnimation("RotTacticalTurnC", "Bridge.Characters.RotLargeAnimations.RotTurnAtTTowardsCaptain")
	pRotFelix.AddAnimation("RotTacticalBackC", "Bridge.Characters.RotLargeAnimations.RotTurnBackAtTFromCaptain")
	#pRotFelix.AddAnimation("EBTacticalTurnE", "Bridge.Characters.RotLargeAnimations.EBTTalkE")
	#pRotFelix.AddAnimation("EBTacticalBackE", "Bridge.Characters.RotLargeAnimations.EBTTalkFinE")
	#pRotFelix.AddAnimation("EBTacticalTurnH", "Bridge.Characters.RotLargeAnimations.EBTTalkH")
	#pRotFelix.AddAnimation("EBTacticalBackH", "Bridge.Characters.RotLargeAnimations.EBTTalkFinH")
	#pRotFelix.AddAnimation("EBTacticalTurnS", "Bridge.Characters.RotLargeAnimations.EBTTalkS")
	#pRotFelix.AddAnimation("EBTacticalBackS", "Bridge.Characters.RotLargeAnimations.EBTTalkFinS")

	#pRotFelix.AddAnimation("EBTacticalTurRot", "Bridge.Characters.RotLargeAnimations.EBTTalkE")
	#pRotFelix.AddAnimation("EBTacticalBackX", "Bridge.Characters.RotLargeAnimations.EBTTalkFinE")

	pRotFelix.AddAnimation("RotTacticalGlanceCaptain", "Bridge.Characters.RotLargeAnimations.RotTConsoleInteraction")
	pRotFelix.AddAnimation("RotTacticalGlanceAwayCaptain", "Bridge.Characters.RotLargeAnimations.Rot_seated_t")

	# Breathing
	pRotFelix.AddAnimation("RotTacticalBreathe", "Bridge.Characters.RotLargeAnimations.Rot_seated_t")
	pRotFelix.AddAnimation("RotTacticalBreatheTurned", "Bridge.Characters.CommonAnimations.BreathingTurned")

	# Roteraction
	pRotFelix.AddRandomAnimation("Bridge.Characters.RotLargeAnimations.RotTConsoleInteraction",App.CharacterClass.SITTING_ONLY, 25, 1)

	# So the mission builders can force the call
	pRotFelix.AddAnimation("PushingButtons", "Bridge.Characters.RotLargeAnimations.RotTConsoleInteraction")

	# Hit animations		
	#pRotFelix.AddAnimation("RotTacticalHit", "Bridge.Characters.RotLargeAnimations.RotTHit")
	#pRotFelix.AddAnimation("RotTacticalHitHard", "Bridge.Characters.RotLargeAnimations.RotTHitHard")
	pRotFelix.AddAnimation("RotTacticalReactLeft", "Bridge.Characters.CommonAnimations.ReactLeft")
	pRotFelix.AddAnimation("RotTacticalReactRight", "Bridge.Characters.CommonAnimations.ReactRight")

	# Add common animations.
	AddCommonAnimations(pRotFelix)
	
	pRotFelix.SetLocation("RotTactical")
	pRotFelix.SetStanding(0)
	pRotFelix.AddPositionZoom("RotTactical", 0.9, "Tactical")
	pRotFelix.SetLookAtAdj(0, 0, 57)
#	kDebugObj.Print("Finished configuring Felix")



###############################################################################
#	AddCommonAnimations()
#
#	Since we can only clear out all animations when switching bridges (how
#	would we know which not to clear?), we can't really setup animations common
#	to all bridge configurations as we might like.  Because of this we have a
#	routine to add common animations (most of which are randoms) that both
#	configurations will call
#
#	Args:	pRotFelix	- our Character object
#
#	Return:	none
###############################################################################
def AddCommonAnimations(pRotFelix):
	#pRotFelix.AddRandomAnimation("Bridge.Characters.RotLargeAnimations.TLookAroundConsoleDown", 1, 1)

	pRotFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadLeft")
	pRotFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadRight")
	pRotFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookUp")
	pRotFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookDown")

	#pRotFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.WipingBrowLeft")
	#pRotFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.WipingBrowRight")
	#pRotFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookLeft")
	#pRotFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookRight")
	#pRotFelix.AddRandomAnimation("Bridge.Characters.CommonAnimations.AtEase", App.CharacterClass.STANDING_ONLY)

###############################################################################
#	OffBridgeStart
#	
#	Sets Felix's location to start in the off bridge partial set
#	
#	Args:	pRotFelix	- our character object
#	
#	Return:	none
###############################################################################
def OffBridgeStart(pRotFelix):
	pRotFelix = App.CharacterClass_Cast(pRotFelix)
	# Nothing else to do, unless you want to change his position

	#Adjust positions of bridge characters here
	pRotFelix.SetTranslateXYZ(0, 0, -15)

	import Bridge.Characters.CommonAnimations
	return Bridge.Characters.CommonAnimations.Standing(pRotFelix)


###############################################################################
#	ConfigureForOffBridge()
#
#	Configure ourselves for another partial set
#
#	Args:	pRotFelix	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForOffBridge(pRotFelix):
#	kDebugObj.Print("Configuring Felix for off bridge")

	# Clear out any old animations from another configuration
	pRotFelix.ClearAnimations()

	# Register animation mappings
	pRotFelix.SetStanding(1)
	pRotFelix.SetHidden(0)
	pRotFelix.SetLocation("KlingonSeated")
	AddCommonAnimations(pRotFelix)

#	kDebugObj.Print("Finished configuring Felix")

###############################################################################
#	LoadSounds
#	
#	Precache Felix's typical voice lines, so they don't hitch the
#	game when they try to play.
#	
#	Args:	None
#	
#	Return:	None
###############################################################################
def LoadSounds():
	pGame = App.Game_GetCurrentGame()
	pDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Crew General.tgl")

	# Loop through all of Felix's voice lines that we want to preload, and load them.
	for sLine in g_lsFelixLines:
		pGame.LoadDatabaseSoundInGroup(pDatabase, sLine, "BridgeGeneric")

	App.g_kLocalizationManager.Unload(pDatabase)

#
# A list of the voice lines we want preloaded for Felix.
#
g_lsFelixLines = (
	"AttackStatus_EvadingTorps1",
	"AttackStatus_FallingBack1",
	"AttackStatus_LiningUpFront1",
	"AttackStatus_MovingIn1",
	"AttackStatus_RearTorpRun1",
	"AttackStatus_SweepingPhasers1",
	"BadTarget1",
	"BadTarget2",
	"Disengaging",
	"DontShootTac",
	"EvasiveManuvers", # Sumbody furgot to spel this rite.
	"FelixEnDes",
	"FelixNothingToAdd",
	"FelixNothingToAdd2",
	"FelixNothingToAdd3",
	"FelixSir1",
	"FelixSir2",
	"FelixSir3",
	"FelixSir4",
	"FelixSir5",
	"FelixYes1",
	"FelixYes2",
	"FelixYes3",
	"FelixYes4",
	"ForeShieldsOffline",
	"Incoming1",
	"Incoming2",
	"Incoming3",
	"Incoming4",
	"Incoming5",
	"Incoming6",
	"LoadingPhoton",
	"LoadingQuantum",
	"LoadingTorps",
	"NeedPower",
	"OutOfPhotons",
	"OutOfQuantums",
	"OutOfType",
	"TacticalManuver", # This wun to.
	"gt001",
	"gt002",
	"gt007",
	"gt029",
	"gt030",
	"gt037",
	"gt038",
	"gt212",
	"gt213",
	)
