###############################################################################
#	Filename:	RotKiska.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	Loads Kiska Lomar, Helm, and configures animations
#	
#	Created:	3/28/00 -	Erik Novales
###############################################################################

import App
import CharacterPaths

#kDebugObj = App.CPyDebug()

###############################################################################
#	CreateCharacter()
#
#	Create Kiska by building her character and placing her on the passed in set.
#	Create her menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacter(pSet):
#	kDebugObj.Print("Creating RotKiska")

	if (pSet.GetObject("Helm") != None):
		return(App.CharacterClass_Cast(pSet.GetObject("Helm")))

	CharacterPaths.UpdatePaths()
	# Create the character

	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyFemM/BodyFemM.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcHeadNIFPath + "HeadSaffi/saffi_head.nif", None)
	pRotKiska = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyFemM/BodyFemM.nif", CharacterPaths.g_pcHeadNIFPath + "HeadSaffi/saffi_head.nif", 1)
	pRotKiska.ReplaceBodyAndHead(CharacterPaths.g_pcBodyTexPath + "../BridgeCrew/Saffi/saffi_body.tga", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/saffi_head.tga")

	pRotKiska.SetCharacterName("Kiska")

	# Add the character to the set
	pSet.AddObjectToSet(pRotKiska, "Helm")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pRotKiska)

	# Setup the character configuration
	pRotKiska.SetSize(App.CharacterClass.MEDIUM)
	pRotKiska.SetGender(App.CharacterClass.FEMALE)
	pRotKiska.SetStanding(0)
	pRotKiska.SetRandomAnimationChance(0.75)
	pRotKiska.SetBlinkChance(0.1)
	pRotKiska.SetDatabase("data/TGL/Bridge Crew General.tgl")

	# Load Helm officer generic sounds
	LoadSounds()

	pRotKiska.AddFacialImage("Blink0", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/Saffi_head_blink1.tga")
	pRotKiska.AddFacialImage("Blink1", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/Saffi_head_blink2.tga")
	pRotKiska.AddFacialImage("Blink2", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/Saffi_head_eyesclosed.tga")
	pRotKiska.SetBlinkStages(3)

	pRotKiska.AddFacialImage("SpeakA", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/saffi_head_a.tga")
	pRotKiska.AddFacialImage("SpeakE", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/saffi_head_e.tga")
	pRotKiska.AddFacialImage("SpeakU", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Saffi/saffi_head_u.tga")
	pRotKiska.SetAnimatedSpeaking(1)

	pGame = App.Game_GetCurrentGame()
	pGame.LoadDatabaseSoundInGroup(pRotKiska.GetDatabase(), "KiskaNothingToAdd", "BridgeGeneric")

	pMenusDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Menus.tgl")
	pTop = App.TopWindow_GetTopWindow()
	pTacticalControlWindow = App.TacticalControlWindow_GetTacticalControlWindow()
	pRotKiska.SetMenu(pTacticalControlWindow.FindMenu(pMenusDatabase.GetString("Helm")))
	App.g_kLocalizationManager.Unload(pMenusDatabase)

#	kDebugObj.Print("Finished creating RotKiska")
	return pRotKiska


###############################################################################
#	ConfigureForShip()
#
#	Configure ourselves for the particular ship object.  This involves setting
#	up range watchers that tell us how to report.
#
#	Args:	pSet	- the Set object
#			pShip	- the player's ship (ShipClass object)
#
#	Return:	none
###############################################################################
def ConfigureForShip(pSet, pShip):
	# Get our character object
	pRotKiska = App.CharacterClass_Cast(pSet.GetObject("Helm"))
	if (pRotKiska == None):
#		kDebugObj.Print("******* Helm officer not found *********")
		return

#	kDebugObj.Print("Attaching menu to Helm..")
	import Bridge.HelmCharacterHandlers
	Bridge.HelmCharacterHandlers.AttachMenuToHelm(pRotKiska)

	#
	# This is where code to set up responses based on the ships state
	# e.g. "Orbiting planet"
	#


###############################################################################
#	ConfigureForRotarran()
#
#	Configure ourselves for the Rotarran bridge
#
#	Args:	pRotKiska	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForRotarran(pRotKiska):
#	kDebugObj.Print("Configuring RotKiska for the Rotarran bridge")

	# Clear out any old animations from another configuration
	pRotKiska.ClearAnimations()

	# Register animation mappings
	pRotKiska.AddAnimation("RotHelmTurnCaptain", "Bridge.Characters.RotMediumAnimations.RotTurnAtHTowardsCaptain")
	pRotKiska.AddAnimation("RotHelmBackCaptain", "Bridge.Characters.RotMediumAnimations.RotTurnBackAtHFromCaptain")


	pRotKiska.AddAnimation("RotHelmGlanceCaptain", "Bridge.Characters.CommonAnimations.GlanceLeft")
	pRotKiska.AddAnimation("RotHelmGlanceAwayCaptain", "Bridge.Characters.RotMediumAnimations.RotHConsoleInteraction")

	# Breathing
	pRotKiska.AddAnimation("EBHelmBreathe", "Bridge.Characters.RotMediumAnimations.Rot_seated_h")

	# Roteraction
	pRotKiska.AddRandomAnimation("Bridge.Characters.RotMediumAnimations.RotHConsoleInteraction", App.CharacterClass.SITTING_ONLY, 25, 1)

	# So the mission builders can force the call
	pRotKiska.AddAnimation("PushingButtons", "Bridge.Characters.RotMediumAnimations.RotHConsoleInteraction")

	# Hit animations
	#pRotKiska.AddAnimation("RotHelmHit", "Bridge.Characters.RotMediumAnimations.RotHHit")
	#pRotKiska.AddAnimation("RotHelmHitHard", "Bridge.Characters.RotMediumAnimations.RotHHitHard")
	pRotKiska.AddAnimation("RotHelmReactLeft", "Bridge.Characters.CommonAnimations.ReactLeft")
	pRotKiska.AddAnimation("RotHelmReactRight", "Bridge.Characters.CommonAnimations.ReactRight")

	# Add common animations.
	AddCommonAnimations(pRotKiska)

	pRotKiska.SetLocation("RotHelm")
	pRotKiska.SetLookAtAdj(0, 0, 57)
	pRotKiska.SetStanding(0)
	pRotKiska.AddPositionZoom("RotHelm", 0.9, "Helm")
#	kDebugObj.Print("Finished configuring RotKiska")


###############################################################################
#	AddCommonAnimations()
#
#	Since we can only clear out all animations when switching bridges (how
#	would we know which not to clear?), we can't really setup animations common
#	to all bridge configurations as we might like.  Because of this we have a
#	routine to add common animations (most of which are randoms) that both
#	configurations will call
#
#	Args:	pRotKiska	- our Character object
#
#	Return:	none
###############################################################################
def AddCommonAnimations(pRotKiska):
	# Roteraction with their environment
	pRotKiska.AddRandomAnimation("Bridge.Characters.RotMediumAnimations.HLookAroundConsoleDown", App.CharacterClass.SITTING_ONLY, 1, 1)

	# Just random stuff
	pRotKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadLeft")
	pRotKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadRight")
	pRotKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookUp")
	pRotKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookDown")

	# These look bad
	#pRotKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.WipingBrowLeft")
	#pRotKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.WipingBrowRight")

	# These force the arms up
	#pRotKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookLeft")
	#pRotKiska.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookRight")

###############################################################################
#	LoadSounds()
#
#	Load generic bridge sounds for this character
#
#	Args:	none
#
#	Return:	none
###############################################################################
def LoadSounds():
	pGame = App.Game_GetCurrentGame()
	pDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Crew General.tgl")

	#
	# Build a list of sound to load
	#
	lSoundList =	[	"KiskaSir1",	# Click Response
						"KiskaSir2",
						"KiskaSir3",
						"KiskaSir4",
						"KiskaSir5",
						
						"KiskaYes1",	# Order Confirmation
						"KiskaYes2",
						"KiskaYes3",
						"KiskaYes4",

						"gh075",	# Course laid in
						"gh081",	# intercept course plotted

						"HailOpen1",
						"HailOpen2",
						"NotResponding1",
						"NotResponding2",
						"OnScreen",

						"CollisionAlert1",
						"CollisionAlert2",
						"CollisionAlert3",
						"CollisionAlert4",
						"CollisionAlert5",
						"CollisionAlert6",
						"CollisionAlert7",
						"CollisionAlert10",

						"IncomingMsg1",
						"IncomingMsg2",
						"IncomingMsg3",
						"IncomingMsg4",
						"IncomingMsg5",
						"IncomingMsg6",
					]
	#
	# Loop through that list, loading each sound in the "BridgeGeneric" group
	#
	for sLine in lSoundList:
		pGame.LoadDatabaseSoundInGroup(pDatabase, sLine, "BridgeGeneric")

	App.g_kLocalizationManager.Unload(pDatabase)
