###############################################################################
#	Filename:	RotMiguel.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	Loads Miguel Diaz, science, and configures animations.
#	
#	Created:	3/28/00 -	Erik Novales
###############################################################################

import App
import CharacterPaths

#kDebugObj = App.CPyDebug()

###############################################################################
#	CreateCharacter()
#
#	Create Miguel by building his character and placing him on the passed in set.
#	Create his menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacter(pSet):
#	kDebugObj.Print("Creating Miguel")

	if (pSet.GetObject("Science") != None):
		return(App.CharacterClass_Cast(pSet.GetObject("Science")))


	CharacterPaths.UpdatePaths()
	# Create the character
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyMaleS/BodyMaleS.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcHeadNIFPath + "HeadMiguel/miguel_head.nif", None)
	pRotMiguel = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyMaleS/BodyMaleS.nif", CharacterPaths.g_pcHeadNIFPath + "HeadMiguel/miguel_head.nif")
	pRotMiguel.ReplaceBodyAndHead(CharacterPaths.g_pcBodyTexPath + "../BridgeCrew/Miguel/miguel_body.tga", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/miguel_head.tga")

	pRotMiguel.SetCharacterName("Miguel")

	# Add the character to the set
	pSet.AddObjectToSet(pRotMiguel, "Science")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pRotMiguel)

	# Setup the character configuration
	pRotMiguel.SetSize(App.CharacterClass.SMALL)
	pRotMiguel.SetGender(App.CharacterClass.MALE)
	pRotMiguel.SetStanding(0)
	pRotMiguel.SetRandomAnimationChance(.75)
	pRotMiguel.SetBlinkChance(0.1)
	pRotMiguel.SetDatabase("data/TGL/Bridge Crew General.tgl")

	# Load Science officer generic sounds
	LoadSounds()

	pRotMiguel.AddFacialImage("Blink0", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_blink1.tga")
	pRotMiguel.AddFacialImage("Blink1", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_blink2.tga")
	pRotMiguel.AddFacialImage("Blink2", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_eyesclosed.tga")
	pRotMiguel.SetBlinkStages(3)

	pRotMiguel.AddFacialImage("SpeakA", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_a.tga")
	pRotMiguel.AddFacialImage("SpeakE", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_e.tga")
	pRotMiguel.AddFacialImage("SpeakU", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/Miguel/Miguel_head_u.tga")
	pRotMiguel.SetAnimatedSpeaking(1)

	pGame = App.Game_GetCurrentGame()
	pGame.LoadDatabaseSoundInGroup(pRotMiguel.GetDatabase(), "MiguelNothingToAdd", "BridgeGeneric")

	pMenusDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Menus.tgl")
	pTop = App.TopWindow_GetTopWindow()
	pTacticalControlWindow = App.TacticalControlWindow_GetTacticalControlWindow()
	pRotMiguel.SetMenu(pTacticalControlWindow.FindMenu(pMenusDatabase.GetString("Science")))
	App.g_kLocalizationManager.Unload(pMenusDatabase)

#	kDebugObj.Print("Finished creating Miguel")
	return pRotMiguel


###############################################################################
#	ConfigureForShip()
#
#	Configure ourselves for the particular ship object.  This involves setting
#	up range watchers that tell us how to report.
#
#	Args:	pSet	- the Set object
#			pShip	- the player's ship (ShipClass object)
#
#	Return:	none
###############################################################################
def ConfigureForShip(pSet, pShip):
	# Get our character object
	pRotMiguel = App.CharacterClass_Cast(pSet.GetObject("Science"))
	if (pRotMiguel == None):
#		kDebugObj.Print("******* Science officer not found *********")
		return

#	kDebugObj.Print("Attaching menu to Science..")
	import Bridge.ScienceCharacterHandlers
	Bridge.ScienceCharacterHandlers.AttachMenuToScience(pRotMiguel)

	#
	# This is where code to set up responses based on the ships state
	# e.g. "Receiving probe data"
	#

###############################################################################
#	ConfigureForRotarran()
#
#	Configure ourselves for the Rotarran bridge
#
#	Args:	pRotMiguel	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForRotarran(pRotMiguel):
#	kDebugObj.Print("Configuring Miguel for the Rotarran bridge")

	# Clear out any old animations from another configuration
	pRotMiguel.ClearAnimations()

	# Register animation mappings
	pRotMiguel.AddAnimation("EBL1SToS", "Bridge.Characters.RotSmallAnimations.EBMoveFromL1ToS")
	pRotMiguel.AddAnimation("EBScienceToL1", "Bridge.Characters.RotSmallAnimations.EBMoveFromSToL1")
	pRotMiguel.AddAnimation("RotScienceTurnCaptain", "Bridge.Characters.RotSmallAnimations.RotTurnAtSTowardsCaptain")
	pRotMiguel.AddAnimation("RotScienceBackCaptain", "Bridge.Characters.RotSmallAnimations.RotTurnBackAtSFromCaptain")

	pRotMiguel.AddAnimation("RotScienceTurnC", "Bridge.Characters.RotSmallAnimations.RotTurnAtSTowardsCaptain")
	pRotMiguel.AddAnimation("RotScienceBackC", "Bridge.Characters.RotSmallAnimations.Rot_stand_s")
	pRotMiguel.AddAnimation("RotScienceTurnH", "Bridge.Characters.RotSmallAnimations.EBSTalkH")
	pRotMiguel.AddAnimation("RotScienceBackH", "Bridge.Characters.RotSmallAnimations.Rot_stand_s")
	pRotMiguel.AddAnimation("RotScienceTurnE", "Bridge.Characters.RotSmallAnimations.EBSTalkE")
	pRotMiguel.AddAnimation("RotScienceBackE", "Bridge.Characters.RotSmallAnimations.Rot_stand_s")
	pRotMiguel.AddAnimation("RotScienceTurnT", "Bridge.Characters.RotSmallAnimations.EBSTalkT")
	pRotMiguel.AddAnimation("RotScienceBackT", "Bridge.Characters.RotSmallAnimations.Rot_stand_s")

	pRotMiguel.AddAnimation("RotScienceTurRot", "Bridge.Characters.RotSmallAnimations.EBSTalkE")
	pRotMiguel.AddAnimation("RotScienceBackX", "Bridge.Characters.RotSmallAnimations.Rot_stand_s")

	pRotMiguel.AddAnimation("RotScienceGlanceCaptain", "Bridge.Characters.CommonAnimations.GlanceLeft")
	pRotMiguel.AddAnimation("RotScienceGlanceAwayCaptain", "Bridge.Characters.RotSmallAnimations.RotSConsoleInteraction")

	pRotMiguel.AddAnimation("EBScienceToS1", "Bridge.Characters.RotSmallAnimations.EBMoveFromSToS1")
	pRotMiguel.AddAnimation("EBScience1ToS", "Bridge.Characters.RotSmallAnimations.EBMoveFromS1ToS")
	pRotMiguel.AddAnimation("EBScienceToS2", "Bridge.Characters.RotSmallAnimations.EBMoveFromSToS2")
	pRotMiguel.AddAnimation("EBScience2ToS", "Bridge.Characters.RotSmallAnimations.EBMoveFromS2ToS")
	pRotMiguel.AddAnimation("EBScience1ToS2", "Bridge.Characters.RotSmallAnimations.EBMoveFromS1ToS2")
	pRotMiguel.AddAnimation("EBScience2ToS1", "Bridge.Characters.RotSmallAnimations.EBMoveFromS2ToS1")

	# Breathing	
	pRotMiguel.AddAnimation("RotScienceBreathe", "Bridge.Characters.RotSmallAnimations.Rot_stand_s")
	pRotMiguel.AddAnimation("RotScienceBreatheTurned", "Bridge.Characters.CommonAnimations.BreathingTurned")

	# Interaction
	pRotMiguel.AddRandomAnimation("Bridge.Characters.RotSmallAnimations.RotSConsoleInteraction", App.CharacterClass.STANDING_ONLY, 25, 1)

	# So the mission builders can force the call
	pRotMiguel.AddAnimation("PushingButtons", "Bridge.Characters.RotSmallAnimations.RotSConsoleInteraction")

	# Hit animations
	pRotMiguel.AddAnimation("RotScienceHitStanding", "Bridge.Characters.CommonAnimations.HitStanding")
	pRotMiguel.AddAnimation("RotScienceHitHardStanding", "Bridge.Characters.CommonAnimations.HitHardStanding")
	pRotMiguel.AddAnimation("RotScienceReactLeftStanding", "Bridge.Characters.CommonAnimations.ReactLeft");
	pRotMiguel.AddAnimation("RotScienceReactRightStanding", "Bridge.Characters.CommonAnimations.ReactRight");

	# Add common animations.
	AddCommonAnimations(pRotMiguel)

	# Miguel stamds on the Rot bridge
	pRotMiguel.SetLocation("RotScience")
	pRotMiguel.SetStanding(1)
	#pRotMiguel.SetLookAtAdj(30, -10, 8)
	pRotMiguel.AddPositionZoom("RotScience", 0.9)
#	kDebugObj.Print("Finished configuring Miguel")



###############################################################################
#	AddCommonAnimations()
#
#	Since we can only clear out all animations when switching bridges (how
#	would we know which not to clear?), we can't really setup animations common
#	to all bridge configurations as we might like.  Because of this we have a
#	routine to add common animations (most of which are randoms) that both
#	configurations will call
#
#	Args:	pRotMiguel	- our Character object
#
#	Return:	none
###############################################################################
def AddCommonAnimations(pRotMiguel):
	pRotMiguel.AddRandomAnimation("Bridge.Characters.RotSmallAnimations.SLookAroundConsoleDown", App.CharacterClass.STANDING_ONLY, 1, 1)

	#pRotMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.WipingBrowLeft")
	#pRotMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.WipingBrowRight")
	pRotMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadLeft")
	pRotMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadRight")
	pRotMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookLeft")
	pRotMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookRight")
	pRotMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookUp")
	pRotMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookDown")
	pRotMiguel.AddRandomAnimation("Bridge.Characters.CommonAnimations.Nod", App.CharacterClass.STANDING_ONLY)


###############################################################################
#	LoadSounds()
#
#	Load generic bridge sounds for this character
#
#	Args:	none
#
#	Return:	none
###############################################################################
def LoadSounds():
	pGame = App.Game_GetCurrentGame()
	pDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Crew General.tgl")
	# Like a function pointer (GetFile() is the same as pDatabase.GetFilename())
	GetFile = pDatabase.GetFilename	# do this for horizontal space savings

	#
	# Build a list of sound to load
	#
	kSoundList =	[	"MiguelSir1",		# Click Response
						"MiguelSir2",
						"MiguelSir3",
						"MiguelSir4",
						"MiguelSir5",

						"MiguelYes1",		# Order Confirmation
						"MiguelYes2",
						"MiguelYes3",
						"MiguelYes4",

						# Scanning lines.
						"MiguelScan",
						"gs038",
						"gs039",
						"gs040",
						"gs041",

						# Launching a probe.
						"gs030",

						# Spontaneous shield callouts.
						"TargetFrontShieldFailed",
						"TargetFrontShieldDraining",
						"TargetRearShieldFailed",
						"TargetRearShieldDraining",
						"TargetLeftShieldFailed",
						"TargetLeftShieldDraining",
						"TargetRightShieldFailed",
						"TargetRightShieldDraining",
						"TargetTopShieldFailed",
						"TargetTopShieldDraining",
						"TargetBottomShieldFailed",
						"TargetBottomShieldDraining",

						# Spontaneous target system callouts..
						"TargetHull05",
						"TargetHull10",
						"TargetHull15",
						"TargetHull20",
						"TargetHull25",
						"TargetHull50",
						"TargetHull75",

						"TargetPhasersDisabled",
						"TargetShieldsDisabled",
						"TargetSensorsDisabled",
						"TargetTorpedoesDisabled",
						"TargetTractorDisabled",
						"TargetImpulseDisabled",
						"TargetWarpDisabled",

						"TargetPhasersDestroyed",
						"TargetShieldsDestroyed",
						"TargetSensorsDestroyed",
						"TargetTorpedoesDestroyed",
						"TargetTractorDestroyed",
						"TargetImpulseDestroyed",
						"TargetWarpDestroyed",
					]
	#
	# Loop through that list, loading each sound in the "BridgeGeneric" group
	#
	for i in range(len(kSoundList)):
		pGame.LoadDatabaseSoundInGroup(pDatabase, kSoundList[i], "BridgeGeneric")

	App.g_kLocalizationManager.Unload(pDatabase)
