###############################################################################
#	Filename:	RotSaffi.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	Loads Saffi Larsen, XO, and configures animations.
#	
#	Created:	3/28/00 -	Erik Novales
###############################################################################

import App
import CharacterPaths

#NonSerializedObjects = ( "debug", )

#debug = App.CPyDebug(__name__).Print

###############################################################################
#	CreateCharacter()
#
#	Create Saffi by building her character and placing her on the passed in set.
#	Create her menus as well.
#
#	Args:	pSet	- the Set in which to place ourselves
#
#	Return:	none
###############################################################################
def CreateCharacter(pSet):
#	debug("Creating Saffi")

	if (pSet.GetObject("XO") != None):
		return(App.CharacterClass_Cast(pSet.GetObject("XO")))
	CharacterPaths.UpdatePaths()
	# Create the character
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyNIFPath + "BodyFemM/BodyFemM.nif", "Bip01")
	App.g_kModelManager.LoadModel(CharacterPaths.g_pcBodyTexPath + "../BridgeCrew/borgqueen/borgqueen_head.nif", None)
	pRotSaffi = App.CharacterClass_Create(CharacterPaths.g_pcBodyNIFPath + "BodyFemM/BodyFemM.nif", CharacterPaths.g_pcHeadNIFPath + "../BridgeCrew/borgqueen/borgqueen_head.nif", 1)
	pRotSaffi.ReplaceBodyAndHead(CharacterPaths.g_pcBodyTexPath + "../BridgeCrew/borgqueen/borgqueen_body.tga", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")

	pRotSaffi.SetCharacterName("Saffi")

	# Add the character to the set
	pSet.AddObjectToSet(pRotSaffi, "XO")
	pLight = pSet.GetLight("ambientlight1")
	pLight.AddIlluminatedObject(pRotSaffi)

	# Setup the character configuration
	pRotSaffi.SetSize(App.CharacterClass.MEDIUM)
	pRotSaffi.SetGender(App.CharacterClass.FEMALE)
	pRotSaffi.SetStanding(1)
	pRotSaffi.SetRandomAnimationChance(.75)
	pRotSaffi.SetBlinkChance(0.1)
	pRotSaffi.SetDatabase("data/TGL/Bridge Crew General.tgl")

	# Load Saffi's general dialogue lines.
	LoadSounds()

	pRotSaffi.AddFacialImage("Blink0", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pRotSaffi.AddFacialImage("Blink1", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pRotSaffi.AddFacialImage("Blink2", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pRotSaffi.SetBlinkStages(3)

	pRotSaffi.AddFacialImage("SpeakA", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pRotSaffi.AddFacialImage("SpeakE", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pRotSaffi.AddFacialImage("SpeakU", CharacterPaths.g_pcHeadTexPath + "../BridgeCrew/borgqueen/borgqueen_head.tga")
	pRotSaffi.SetAnimatedSpeaking(1)

	pMenusDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Menus.tgl")
	pTop = App.TopWindow_GetTopWindow()
	pTacticalControlWindow = App.TacticalControlWindow_GetTacticalControlWindow()
	pRotSaffi.SetMenu(pTacticalControlWindow.FindMenu(pMenusDatabase.GetString("Commander")))
	App.g_kLocalizationManager.Unload(pMenusDatabase)

#	debug("Finished creating Saffi")
	return pRotSaffi


###############################################################################
#	ConfigureForShip()
#
#	Configure ourselves for the particular ship object.  This involves setting
#	up range watchers that tell us how to report.
#
#	Args:	pSet	- the Set object
#			pShip	- the player's ship (ShipClass object)
#
#	Return:	none
###############################################################################
def ConfigureForShip(pSet, pShip):
	# Get our character object
	pRotSaffi = App.CharacterClass_Cast(pSet.GetObject("XO"))
	if (pRotSaffi == None):
#		debug("******* Commanding officer not found *********")
		return

#	debug("Attaching menu to XO..")
	import Bridge.XOCharacterHandlers
	Bridge.XOCharacterHandlers.AttachMenuToXO(pRotSaffi)

	#
	# This is where code to set up responses based on the ships state
	# e.g. "Main power back on line"
	#

###############################################################################
#	ConfigureForRotarran()
#
#	Configure ourselves for the Rotarran bridge
#
#	Args:	pRotSaffi	- our Character object
#
#	Return:	none
###############################################################################
def ConfigureForRotarran(pRotSaffi):
#	debug("Configuring Saffi for the Rotarran bridge")

	# Clear out any old animations from another configuration
	pRotSaffi.ClearAnimations()

	# Register animation mappings
	pRotSaffi.AddAnimation("SeatedRotCommander", "Bridge.Characters.RotMediumAnimations.Rot_stand_C_M")
	pRotSaffi.AddAnimation("StandingRotCommander", "Bridge.Characters.RotMediumAnimations.Rot_stand_C_M")
	pRotSaffi.AddAnimation("EBL1MToEBCommander", "Bridge.Characters.RotMediumAnimations.EBMoveFromL1ToC")
	pRotSaffi.AddAnimation("EBCommanderToL1", "Bridge.Characters.RotMediumAnimations.EBMoveFromCToL1")
	pRotSaffi.AddAnimation("RotCommanderTurnCaptain", "Bridge.Characters.RotMediumAnimations.RotTurnAtCTowardsCaptain")
	pRotSaffi.AddAnimation("RotCommanderBackCaptain", "Bridge.Characters.RotMediumAnimations.RotTurnBackAtCFromCaptain")

	pRotSaffi.AddAnimation("RotCommanderGlanceCaptain", "Bridge.Characters.CommonAnimations.GlanceLeft")
	pRotSaffi.AddAnimation("RotCommanderGlanceAwayCaptain", "Bridge.Characters.RotMediumAnimations.RotCConsoleInteraction")
	pRotSaffi.AddAnimation("RotCommander1GlanceCaptain", "Bridge.Characters.CommonAnimations.GlanceLeft")
	pRotSaffi.AddAnimation("RotCommander1GlanceAwayCaptain", "Bridge.Characters.RotMediumAnimations.RotCConsoleInteraction")

	pRotSaffi.AddAnimation("EBCommanderTurnE", "Bridge.Characters.RotMediumAnimations.EBCTalkE")
	pRotSaffi.AddAnimation("EBCommanderBackE", "Bridge.Characters.RotMediumAnimations.Rot_seated_C")
	pRotSaffi.AddAnimation("EBCommanderTurnH", "Bridge.Characters.RotMediumAnimations.EBCTalkH")
	pRotSaffi.AddAnimation("EBCommanderBackH", "Bridge.Characters.RotMediumAnimations.Rot_seated_C")
	pRotSaffi.AddAnimation("EBCommanderTurnT", "Bridge.Characters.RotMediumAnimations.EBCTalkT")
	pRotSaffi.AddAnimation("EBCommanderBackT", "Bridge.Characters.RotMediumAnimations.Rot_seated_C")
	pRotSaffi.AddAnimation("EBCommanderTurnS", "Bridge.Characters.RotMediumAnimations.EBCTalkS")
	pRotSaffi.AddAnimation("EBCommanderBackS", "Bridge.Characters.RotMediumAnimations.Rot_seated_C")

	pRotSaffi.AddAnimation("EBCommanderTurRot", "Bridge.Characters.RotMediumAnimations.EBCTalkE")
	pRotSaffi.AddAnimation("EBCommanderBackX", "Bridge.Characters.RotMediumAnimations.Rot_seated_C")

	# Breathing
	pRotSaffi.AddAnimation("RotCommanderBreathe", "Bridge.Characters.RotMediumAnimations.Rot_seated_C")
	pRotSaffi.AddAnimation("RotCommander1Breathe", "Bridge.Characters.RotMediumAnimations.Rot_seated_C")
	pRotSaffi.AddAnimation("RotCommanderBreatheTurned", "Bridge.Characters.CommonAnimations.BreathingTurned")
	pRotSaffi.AddAnimation("RotCommander1BreatheTurned", "Bridge.Characters.CommonAnimations.BreathingTurned")

	# Interaction
	pRotSaffi.AddRandomAnimation("Bridge.Characters.RotMediumAnimations.RotCConsoleInteraction", App.CharacterClass.STANDING_ONLY, 25, 1)
	pRotSaffi.AddAnimation("PushingButtons", "Bridge.Characters.RotMediumAnimations.RotCConsoleInteraction")

	# Hit animations
	pRotSaffi.AddAnimation("RotCommanderHit", "Bridge.Characters.RotMediumAnimations.RotCHit")
	pRotSaffi.AddAnimation("RotCommanderHitHard", "Bridge.Characters.RotMediumAnimations.RotCHitHard")
	#pRotSaffi.AddAnimation("EBCommanderHitStanding", "Bridge.Characters.CommonAnimations.HitStanding")
	#pRotSaffi.AddAnimation("EBCommanderHitHardStanding", "Bridge.Characters.CommonAnimations.HitHardStanding")
	pRotSaffi.AddAnimation("RotCommanderReactLeft", "Bridge.Characters.CommonAnimations.ReactLeft")
	pRotSaffi.AddAnimation("RotCommanderReactRight", "Bridge.Characters.CommonAnimations.ReactRight")

	# Add common animations.
	AddCommonAnimations(pRotSaffi)
	pRotSaffi.SetStanding(1)
	pRotSaffi.SetLocation("RotCommander")
	pRotSaffi.AddPositionZoom("RotCommander", 1.0)
#	debug("Finished configuring Saffi")

###############################################################################
#	AddCommonAnimations()
#
#	Since we can only clear out all animations when switching bridges (how
#	would we know which not to clear?), we can't really setup animations common
#	to all bridge configurations as we might like.  Because of this we have a
#	routine to add common animations (most of which are randoms) that both
#	configurations will call
#
#	Args:	pRotSaffi	- our Character object
#
#	Return:	none
###############################################################################
def AddCommonAnimations(pRotSaffi):
	pRotSaffi.AddRandomAnimation("Bridge.Characters.RotMediumAnimations.CLookAroundConsoleDown", App.CharacterClass.STANDING_ONLY, 1, 1)

	pRotSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadLeft")
	pRotSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.TiltHeadRight")
	pRotSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookLeft", App.CharacterClass.STANDING_ONLY)
	pRotSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookRight", App.CharacterClass.STANDING_ONLY)
	pRotSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookUp", App.CharacterClass.STANDING_ONLY)
	pRotSaffi.AddRandomAnimation("Bridge.Characters.CommonAnimations.LookDown", App.CharacterClass.STANDING_ONLY)

###############################################################################
#	LoadSounds
#	
#	Load any of Saffi's general or spontaneous sounds, so they don't
#	hitch the game when they're played.
#	
#	Args:	None
#	
#	Return:	None
###############################################################################
def LoadSounds():
	pGame = App.Game_GetCurrentGame()
	pDatabase = App.g_kLocalizationManager.Load("data/TGL/Bridge Crew General.tgl")
	
	#
	# Build a list of sound to load
	#
	lSoundList =	[
		# Yes?
		"gf001",
		"gf002",

		# Report.
		"gf020",

		# Alert lines.
		"GreenAlert",
		"GreenAlert2",
		"GreenAlert3",
		"YellowAlert",
		"YellowAlert3",
		"YellowAlert2",
		"RedAlert",
		"RedAlert2",

		# Contacting starfleet.
		"gl004",
		"gl005",
					]
	#
	# Loop through that list, loading each sound in the "BridgeGeneric" group
	#
	for sLine in lSoundList:
		pGame.LoadDatabaseSoundInGroup(pDatabase, sLine, "BridgeGeneric")

	App.g_kLocalizationManager.Unload(pDatabase)
