##############################################################################
#	Filename:	Rotbridge.py
#	
#	Confidential and Proprietary, Copyright 2000 by Totally Games
#	
#	This contains the code to create and configure the Rot class bridge.
#	It is only called by LoadBridge.Initialize("Rotbridge"), so don't
#	call these functions directly
#
#	Created:	9/12/00 -	DLitwin
###############################################################################
import App

#NonSerializedObjects = ( "debug", )

#debug = App.CPyDebug(__name__).Print
#debug("Loading " + __name__ + " module...")

###############################################################################
#	CreateBridgeModel()
#
#	Create the Rot bridge model, viewscreen and main camera, attaching them
#	to the Set passed in.
#
#	Args:	pBridgeSet	- The Bridge set
#
#	Return:	none
###############################################################################
def CreateBridgeModel(pBridgeSet):
	iDetail = App.g_kImageManager.GetImageDetail()
	pcDetail = [ "Low/", "Medium/", "High/" ]
	pcEnvPath = "data/Models/Sets/Rotbridge/" + pcDetail[iDetail]

	# Pre-load the Bridge model and viewscreen
	App.g_kModelManager.LoadModel("data/Models/Sets/Rotbridge/Rotbridge.nif", None, pcEnvPath)
	App.g_kModelManager.LoadModel("data/Models/Sets/Rotbridge/RotViewScreen.NIF", None, pcEnvPath)

	# Load the viewscreen and set it up specially with SetViewScreen()
	pViewScreen = App.ViewScreenObject_Create("data/Models/Sets/Rotbridge/RotViewScreen.NIF")
	pBridgeSet.SetViewScreen(pViewScreen, "viewscreen")

	# Setup bridge object
	pBridgeObject = App.BridgeObjectClass_Create("data/Models/Sets/Rotbridge/Rotbridge.nif")
	pBridgeSet.AddObjectToSet(pBridgeObject, "bridge")
	pBridgeObject.SetTranslateXYZ(0.000000, 0.000000, 0.000000)
	pBridgeObject.SetAngleAxisRotation(0.000000, 1.000000, 0.000000, 0.000000)

	# setup hardpoints for dbridge.
	pPropertySet = pBridgeObject.GetPropertySet()
	import Bridge.RotbridgeProperties
	App.g_kModelPropertyManager.ClearLocalTemplates()
	reload(Bridge.RotbridgeProperties)
	Bridge.RotbridgeProperties.LoadPropertySet(pPropertySet)


	# Create camera
	lPos = GetBaseCameraPosition()
	pCamera = App.ZoomCameraObjectClass_Create(lPos[0], lPos[1], lPos[2], 1.570796, -0.000665, -0.087559, 0.996159, "maincamera")
	pCamera.SetMinZoom(0.8)
	pCamera.SetMaxZoom(1.0)
	pCamera.SetZoomTime(0.375)
	pBridgeSet.AddCameraToSet(pCamera, "maincamera")
	pCamera.Update( App.g_kUtopiaModule.GetGameTime() )
	App.g_kVarManager.SetFloatVariable("global", "fZoomTuneState", 0)

	# Load Rot bridge specific sounds
	LoadSounds()

	App.g_kModelPropertyManager.ClearLocalTemplates()

###############################################################################
#	GetBaseCameraPosition
#	
#	Get the normal camera position for this bridge.
#	
#	Args:	None
#	
#	Return:	A tuple with the (x,y,z) location for the base camera position.
###############################################################################
def GetBaseCameraPosition():
	return (0, 0, 0)

###############################################################################
#	AdjustCameraPositionForBridge
#	
#	Adjust the position of the camera, based on the horizontal
#	angle it's facing, based on the bridge that it's on.
#	
#	Args:	fHorizAngle
#	
#	Return:	The adjusted camera position.
###############################################################################
def AdjustCameraPositionForBridge(pCamera, fHorizAngle):
	vLocation = App.TGPoint3()
	apply(vLocation.SetXYZ, GetBaseCameraPosition())
	return vLocation

###############################################################################
#	ConfigureCharacters()
#
#	Configure the bridge crew to the set, which adds bridge specific animations
#	to them.
#
#	Args:	pBridgeSet	- The Bridge set
#
#	Return:	none
###############################################################################
def ConfigureCharacters(pBridgeSet):
	# Configure bridge characters to our bridge
	import Bridge.Characters.RotFelix
	import Bridge.Characters.RotKiska
	import Bridge.Characters.RotSaffi
	import Bridge.Characters.RotBrex
	import Bridge.Characters.RotMiguel
	
	pRotFelix = App.CharacterClass_Cast(pBridgeSet.GetObject("Tactical"))
	pRotKiska = App.CharacterClass_Cast(pBridgeSet.GetObject("Helm"))
	pRotSaffi = App.CharacterClass_Cast(pBridgeSet.GetObject("XO"))
	pRotMiguel = App.CharacterClass_Cast(pBridgeSet.GetObject("Science"))
	pRotBrex = App.CharacterClass_Cast(pBridgeSet.GetObject("Engineer"))
	
	Bridge.Characters.RotFelix.ConfigureForRotarran(pRotFelix)
	Bridge.Characters.RotKiska.ConfigureForRotarran(pRotKiska)
	Bridge.Characters.RotSaffi.ConfigureForRotarran(pRotSaffi)
	Bridge.Characters.RotMiguel.ConfigureForRotarran(pRotMiguel)
	Bridge.Characters.RotBrex.ConfigureForRotarran(pRotBrex)
		
	pCamera = App.ZoomCameraObjectClass_GetObject(pBridgeSet, "maincamera")
	pCamera.SetTranslateXYZ(0, 0, 57)



###############################################################################
#	LoadSounds()
#
#	Load any Rotarran bridge specific sounds
#
#	Args:	none
#
#	Return:	none
###############################################################################
def LoadSounds():

#	debug("Loading Rotarran door sound")

	pGame = App.Game_GetCurrentGame()
	pGame.LoadSoundInGroup("sfx/door.wav",  "LiftDoor", "BridgeGeneric")

#	debug("Loading Rotarran red alert sound")

	pGame = App.Game_GetCurrentGame()
	pGame.LoadSoundInGroup("sfx/redalert.wav",  "RedAlertSound", "BridgeGeneric")

#	debug("Loading Rotarran hail sound")

	pGame = App.Game_GetCurrentGame()
	pGame.LoadSoundInGroup("sfx/TMP-hail.wav",  "Hail", "BridgeGeneric")

#	debug("Loading Rotarran Rotient sound")

	pGame = App.Game_GetCurrentGame()
	pGame.LoadSoundInGroup("sfx/bridge2.loop.wav",  "RotBridge", "BridgeGeneric")


###############################################################################
#	UnloadSounds()
#
#	Unload any Rotarran bridge specific sounds
#
#	Args:	none
#
#	Return:	none
###############################################################################
def UnloadSounds():
	App.g_kSoundManager.DeleteSound("LiftDoor")
        App.g_kSoundManager.DeleteSound("RedAlertSound")
	App.g_kSoundManager.DeleteSound("Hail")
	App.g_kSoundManager.DeleteSound("RotBridge")


###############################################################################
#	PreloadAnimations()
#
#	Load any Rotarran bridge specific animations that are common
#
#	Args:	none
#
#	Return:	none
###############################################################################
def PreloadAnimations ():
	kAM = App.g_kAnimationManager

	kAM.LoadAnimation ("data/animations/RotTNG_door_L1.NIF", "Rot_Door_L1")
	kAM.LoadAnimation ("data/animations/RotTNG_door_L2.nif", "Rot_Door_L2")
	kAM.LoadAnimation ("data/animations/Rot_door_L1.NIF", "Rot_Door_L1")
	kAM.LoadAnimation ("data/animations/Rot_door_L2.nif", "Rot_Door_L2")

	# Small animations
	# Science Movement
	kAM.LoadAnimation ("data/animations/Rot_stand_s_s.nif", "Rot_stand_s_s")
	kAM.LoadAnimation ("data/animations/Rot_seated_s_s.nif", "Rot_seated_s_s")
	kAM.LoadAnimation ("data/animations/EB_chair_S_in.nif", "EB_chair_S_in")

	# Science Console Slides and Button Pushes
	kAM.LoadAnimation ("data/animations/EB_E_pushing_buttons_seated_A.NIF", "EB_E_pushing_buttons_seated_A")
	kAM.LoadAnimation ("data/animations/EB_E_pushing_buttons_seated_B.NIF", "EB_E_pushing_buttons_seated_B")
	kAM.LoadAnimation ("data/animations/EB_E_pushing_buttons_seated_C.NIF", "EB_E_pushing_buttons_seated_C")

	# Science Talking to other stations

	# Engineer Movement
	kAM.LoadAnimation ("data/animations/Rot_stand_e_s.nif", "Rot_stand_e_s")
	kAM.LoadAnimation ("data/animations/Rot_seated_e_s.nif", "Rot_seated_e_s")
	kAM.LoadAnimation ("data/animations/EB_chair_E_in.nif", "EB_chair_E_in")

	# Engineer Console Slides and Button Pushes
	kAM.LoadAnimation ("data/animations/EB_E_pushing_buttons_seated_A.NIF", "EB_E_pushing_buttons_seated_A")
	kAM.LoadAnimation ("data/animations/EB_E_pushing_buttons_seated_B.NIF", "EB_E_pushing_buttons_seated_B")
	kAM.LoadAnimation ("data/animations/EB_E_pushing_buttons_seated_C.NIF", "EB_E_pushing_buttons_seated_C")

	# Engineer Talking to other stations

	# 
	# medium animations
	# Helm Movement
	kAM.LoadAnimation ("data/animations/Rot_stand_h_m.nif", "Rot_stand_h_m")
	kAM.LoadAnimation ("data/animations/Rot_seated_h_m.nif", "Rot_seated_h_m")
	kAM.LoadAnimation ("data/animations/EB_glance_h_m.nif", "Rot_glance_h_m")
	kAM.LoadAnimation ("data/animations/EB_glance_h_m_reverse.nif", "Rot_glance_h_m_reverse")
	kAM.LoadAnimation ("data/animations/Rot_seated_H.nif", "Rot_seated_h")
	#kAM.LoadAnimation ("data/animations/Rot_interaction_H.nif", "Rot_interaction_h")

	kAM.LoadAnimation ("data/animations/EB_hit_h.NIF", "Rot_hit_h")


	# Helm Console Slides and Button Pushes
	kAM.LoadAnimation ("data/animations/Rot_H_pushing_buttons_A.NIF", "EB_H_console_slide_A")
	kAM.LoadAnimation ("data/animations/Rot_H_pushing_buttons_A.NIF", "EB_H_console_slide_B")
	kAM.LoadAnimation ("data/animations/Rot_T_pushing_buttons_A.NIF", "EB_H_console_slide_C")
	kAM.LoadAnimation ("data/animations/Rot_T_pushing_buttons_A.NIF", "EB_H_console_slide_D")

	kAM.LoadAnimation ("data/animations/Rot_H_pushing_buttons_A.NIF", "EB_H_pushing_buttons_A")
	kAM.LoadAnimation ("data/animations/Rot_H_pushing_buttons_A.NIF", "EB_H_pushing_buttons_B")
	kAM.LoadAnimation ("data/animations/Rot_H_pushing_buttons_A.NIF", "EB_H_pushing_buttons_C")
	kAM.LoadAnimation ("data/animations/Rot_T_pushing_buttons_A.NIF", "EB_H_pushing_buttons_D")
	kAM.LoadAnimation ("data/animations/Rot_T_pushing_buttons_A.NIF", "EB_H_pushing_buttons_E")
	kAM.LoadAnimation ("data/animations/Rot_T_pushing_buttons_A.NIF", "EB_H_pushing_buttons_F")

	# Helm Talking to other stations
	kAM.LoadAnimation ("data/animations/EB_H_Talk_to_C_M.NIF", "EB_H_Talk_to_C_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_to_E_M.NIF", "EB_H_Talk_to_E_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_to_S_M.NIF", "EB_H_Talk_to_S_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_to_T_M.NIF", "EB_H_Talk_to_T_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_fin_C_M.NIF", "EB_H_Talk_fin_C_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_fin_E_M.NIF", "EB_H_Talk_fin_E_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_fin_S_M.NIF", "EB_H_Talk_fin_S_M")
	kAM.LoadAnimation ("data/animations/EB_H_Talk_fin_T_M.NIF", "EB_H_Talk_fin_T_M")

	# XO Movement
	kAM.LoadAnimation ("data/animations/Rot_stand_C_M.nif", "Rot_stand_c_m")
	

	#Commander interaction
	#kAM.LoadAnimation ("data/animations/Rot_C_pushing_buttons_A.NIF", "EB_C_pushing_buttons_seated_A")
	#kAM.LoadAnimation ("data/animations/Rot_C_pushing_buttons_A.NIF", "EB_C_pushing_buttons_seated_B")
	#kAM.LoadAnimation ("data/animations/Rot_s_pushing_buttons_A.NIF", "EB_C_pushing_buttons_seated_C")
	#kAM.LoadAnimation ("data/animations/Rot_e_pushing_buttons_A.NIF", "EB_C_pushing_buttons_seated_D")
	#kAM.LoadAnimation ("data/animations/Rot_s_pushing_buttons_A.NIF", "EB_C_pushing_buttons_seated_E")
	#kAM.LoadAnimation ("data/animations/Rot_e_pushing_buttons_A.NIF", "EB_C_pushing_buttons_seated_F")
	#kAM.LoadAnimation ("data/animations/Rot_e_pushing_buttons_A.NIF", "EB_C_pushing_buttons_seated_G")

	#kAM.LoadAnimation ("data/animations/EB_X_pushing_buttons_A.NIF", "EB_X_pushing_buttons_A")
	#kAM.LoadAnimation ("data/animations/EB_X_pushing_buttons_B.NIF", "EB_X_pushing_buttons_B")
	#kAM.LoadAnimation ("data/animations/EB_X_pushing_buttons_C.NIF", "EB_X_pushing_buttons_C")
	#kAM.LoadAnimation ("data/animations/EB_X_pushing_buttons_D.NIF", "EB_X_pushing_buttons_D")
	#kAM.LoadAnimation ("data/animations/EB_X_pushing_buttons_E.NIF", "EB_X_pushing_buttons_E")
	#kAM.LoadAnimation ("data/animations/EB_X_pushing_buttons_F.NIF", "EB_X_pushing_buttons_F")
	#kAM.LoadAnimation ("data/animations/EB_X_pushing_buttons_G.NIF", "EB_X_pushing_buttons_G")

	# XO Talking to other stations
	kAM.LoadAnimation ("data/animations/EB_C_Talk_E_M.NIF", "EB_C_Talk_E_M")
	kAM.LoadAnimation ("data/animations/EB_C_Talk_G2_M.NIF", "EB_C_Talk_G2_M")
	kAM.LoadAnimation ("data/animations/EB_C_Talk_G3_M.NIF", "EB_C_Talk_G3_M")
	kAM.LoadAnimation ("data/animations/EB_C_Talk_TH_M.NIF", "EB_C_Talk_TH_M")
	kAM.LoadAnimation ("data/animations/EB_C_Talk_S_M.NIF", "EB_C_Talk_S_M")

	# Guest Animations
	kAM.LoadAnimation ("data/animations/EB_L1toX_M.nif", "EB_L1toX_M")
	kAM.LoadAnimation ("data/animations/EB_seated_X_m.nif", "EB_seated_X_m")
	kAM.LoadAnimation ("data/animations/EB_face_capt_X.nif", "EB_face_capt_X")
	kAM.LoadAnimation ("data/animations/EB_face_capt_X_reverse.NIF", "EB_face_capt_X_reverse")
	kAM.LoadAnimation ("data/animations/EB_hit_x.NIF", "Rot_hit_x")

	# Extras
	
		
	# Large animations
	# Tactical Movement
	kAM.LoadAnimation ("data/animations/Rot_stand_t_l.nif", "Rot_stand_t_l")
	kAM.LoadAnimation ("data/animations/Rot_seated_t_l.nif", "Rot_seated_t_l")
	kAM.LoadAnimation ("data/animations/EB_hit_t.NIF", "Rot_hit_t")

	# Tactical Console Slides and Button Pushes
	kAM.LoadAnimation ("data/animations/Rot_T_pushing_buttons_A.NIF", "EB_T_console_slide_A")
	kAM.LoadAnimation ("data/animations/Rot_T_pushing_buttons_A.NIF", "EB_T_console_slide_B")
	kAM.LoadAnimation ("data/animations/Rot_H_pushing_buttons_A.NIF", "EB_T_console_slide_C")
	kAM.LoadAnimation ("data/animations/Rot_H_pushing_buttons_A.NIF", "EB_T_console_slide_D")

	kAM.LoadAnimation ("data/animations/Rot_T_pushing_buttons_A.NIF", "EB_T_pushing_buttons_A")
	kAM.LoadAnimation ("data/animations/Rot_T_pushing_buttons_A.NIF", "EB_T_pushing_buttons_B")
	kAM.LoadAnimation ("data/animations/Rot_T_pushing_buttons_A.NIF", "EB_T_pushing_buttons_C")
	kAM.LoadAnimation ("data/animations/Rot_H_pushing_buttons_A.NIF", "EB_T_pushing_buttons_D")
	kAM.LoadAnimation ("data/animations/Rot_H_pushing_buttons_A.NIF", "EB_T_pushing_buttons_E")
	kAM.LoadAnimation ("data/animations/Rot_H_pushing_buttons_A.NIF", "EB_T_pushing_buttons_F")

	# Tactical Talking to other stations
	kAM.LoadAnimation ("data/animations/EB_T_Talk_to_H_L.NIF", "EB_T_Talk_to_H_L")
	kAM.LoadAnimation ("data/animations/EB_T_Talk_to_G2_L.NIF", "EB_T_Talk_to_G2_L")
	kAM.LoadAnimation ("data/animations/EB_T_Talk_to_G3_L.NIF", "EB_T_Talk_to_G3_L")

	kAM.LoadAnimation ("data/animations/EB_T_Talk_fin_H_L.NIF", "EB_T_Talk_fin_H_L")
	kAM.LoadAnimation ("data/animations/EB_T_Talk_fin_G2_L.NIF", "EB_T_Talk_fin_G2_L")
	kAM.LoadAnimation ("data/animations/EB_T_Talk_fin_G3_L.NIF", "EB_T_Talk_fin_G3_L")

	return

###############################################################################
#	UnloadAnimations()
#
#	Unload any Rotarran bridge specific animations that are common
#
#	Args:	none
#
#	Return:	none
###############################################################################
def UnloadAnimations ():
	kAM = App.g_kAnimationManager

	kAM.FreeAnimation("Rot_Door_L1")
	kAM.FreeAnimation("Rot_Door_L2")

	# Small animations
	# Science Movement
	kAM.FreeAnimation("Rot_stand_s_s")
	kAM.FreeAnimation("Rot_seated_s_s")
	kAM.FreeAnimation("EB_chair_S_in")


	# Science Console Slides and Button Pushes
	kAM.FreeAnimation("EB_E_pushing_buttons_seated_A")
	kAM.FreeAnimation("EB_E_pushing_buttons_seated_B")
	kAM.FreeAnimation("EB_E_pushing_buttons_seated_C")

	# Science Talking to other stations

	# Engineer Movement
	kAM.FreeAnimation("Rot_stand_e_s")
	kAM.FreeAnimation("Rot_seated_e_s")
	kAM.FreeAnimation("EB_chair_E_in")

	# Engineer Console Slides and Button Pushes
	kAM.FreeAnimation("EB_E_pushing_buttons_seated_A")
	kAM.FreeAnimation("EB_E_pushing_buttons_seated_B")
	kAM.FreeAnimation("EB_E_pushing_buttons_seated_C")

	# Engineer Talking to other stations

	# medium animations
	# Helm Movement
	kAM.FreeAnimation("Rot_stand_h_m")
	kAM.FreeAnimation("Rot_seated_h_m")
	kAM.FreeAnimation("Rot_face_capt_h")
	kAM.FreeAnimation("Rot_chair_h_face_capt")
	kAM.FreeAnimation("Rot_face_capt_h_reverse")
	kAM.FreeAnimation("Rot_chair_h_face_capt_reverse")
	kAM.FreeAnimation("Rot_seated_h")
	#kAM.FreeAnimation("Rot_interaction_h")
	kAM.FreeAnimation("Rot_hit_h")


	# Helm Console Slides and Button Pushes
	kAM.FreeAnimation("EB_H_console_slide_A")
	kAM.FreeAnimation("EB_H_console_slide_B")
	kAM.FreeAnimation("EB_H_console_slide_C")
	kAM.FreeAnimation("EB_H_console_slide_D")

	kAM.FreeAnimation("EB_H_pushing_buttons_A")
	kAM.FreeAnimation("EB_H_pushing_buttons_B")
	kAM.FreeAnimation("EB_H_pushing_buttons_C")
	kAM.FreeAnimation("EB_H_pushing_buttons_D")
	kAM.FreeAnimation("EB_H_pushing_buttons_E")
	kAM.FreeAnimation("EB_H_pushing_buttons_F")

	# Helm Talking to other stations
	kAM.FreeAnimation("EB_H_Talk_to_C_M")
	kAM.FreeAnimation("EB_H_Talk_to_E_M")
	kAM.FreeAnimation("EB_H_Talk_to_S_M")
	kAM.FreeAnimation("EB_H_Talk_to_T_M")
	kAM.FreeAnimation("EB_H_Talk_fin_C_M")
	kAM.FreeAnimation("EB_H_Talk_fin_E_M")
	kAM.FreeAnimation("EB_H_Talk_fin_S_M")
	kAM.FreeAnimation("EB_H_Talk_fin_T_M")

	# XO Movement
	kAM.FreeAnimation("Rot_stand_c_m")
	kAM.FreeAnimation("Rot_hit_c")

	# XO Console Slides and Button Pushes
	kAM.FreeAnimation("EB_C_pushing_buttons_seated_A")
	kAM.FreeAnimation("EB_C_pushing_buttons_seated_B")
	kAM.FreeAnimation("EB_C_pushing_buttons_seated_C")
	kAM.FreeAnimation("EB_C_pushing_buttons_seated_D")
	kAM.FreeAnimation("EB_C_pushing_buttons_seated_E")
	kAM.FreeAnimation("EB_C_pushing_buttons_seated_F")
	kAM.FreeAnimation("EB_C_pushing_buttons_seated_G")

	# XO Talking to other stations
	kAM.FreeAnimation("EB_C_Talk_E_M")
	kAM.FreeAnimation("EB_C_Talk_H_M")
	kAM.FreeAnimation("EB_C_Talk_T_M")
	kAM.FreeAnimation("EB_C_Talk_S_M")

	# Guest Animations
	kAM.FreeAnimation("EB_L1toX_M")
	kAM.FreeAnimation("EB_seated_X_m")
	kAM.FreeAnimation("EB_face_capt_X")
	kAM.FreeAnimation("EB_face_capt_X_reverse")
	kAM.FreeAnimation("Rot_hit_x")

	kAM.FreeAnimation("EB_X_pushing_buttons_A")
	kAM.FreeAnimation("EB_X_pushing_buttons_B")
	kAM.FreeAnimation("EB_X_pushing_buttons_C")
	kAM.FreeAnimation("EB_X_pushing_buttons_D")
	kAM.FreeAnimation("EB_X_pushing_buttons_E")
	kAM.FreeAnimation("EB_X_pushing_buttons_F")
	kAM.FreeAnimation("EB_X_pushing_buttons_G")

	#Extra
	
	# Large animations
	# Tactical Movement
	kAM.FreeAnimation("Rot_stand_t_l")
	kAM.FreeAnimation("Rot_seated_t_l")
	kAM.FreeAnimation("Rot_seated_t")
	kAM.FreeAnimation("Rot_hit_t")

	# Tactical Console Slides and Button Pushes
	kAM.FreeAnimation("EB_T_console_slide_A")
	kAM.FreeAnimation("EB_T_console_slide_B")
	kAM.FreeAnimation("EB_T_console_slide_C")
	kAM.FreeAnimation("EB_T_console_slide_D")

	kAM.FreeAnimation("EB_T_pushing_buttons_A")
	kAM.FreeAnimation("EB_T_pushing_buttons_B")
	kAM.FreeAnimation("EB_T_pushing_buttons_C")
	kAM.FreeAnimation("EB_T_pushing_buttons_D")
	kAM.FreeAnimation("EB_T_pushing_buttons_E")
	kAM.FreeAnimation("EB_T_pushing_buttons_F")

	# Tactical Talking to other stations
	kAM.FreeAnimation("EB_T_Talk_to_H_L")
	kAM.FreeAnimation("EB_T_Talk_to_G2_L")
	kAM.FreeAnimation("EB_T_Talk_to_G3_L")

	kAM.FreeAnimation("EB_T_Talk_fin_H_L")
	kAM.FreeAnimation("EB_T_Talk_fin_G2_L")
	kAM.FreeAnimation("EB_T_Talk_fin_G3_L")


	return
